/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef NU8 tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA;
typedef NU8 tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg;
struct tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ {
FILE* f;
tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA currentSection;
tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg err;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w;
typedef NU8 tyArray__cdsir9aPB24hAk6k77P9b9bCA[8];
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, open__systemZio_389)(FILE** f, NimStringDesc* filename, tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w mode, NI bufSize);
static N_INLINE(void, setError__icZrodfiles_52)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg err);
N_LIB_PRIVATE N_NIMCALL(NI, readBytes__icZrodfiles_159)(FILE* f, NU8* a, NI aLen_0, NI start, NI len);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___icZrodfiles_173)(tyArray__cdsir9aPB24hAk6k77P9b9bCA x, tyArray__cdsir9aPB24hAk6k77P9b9bCA y);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZrodfiles_264)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA* x);
N_LIB_PRIVATE N_NIMCALL(NI, readBuffer__systemZio_144)(FILE* f, void* buffer, NI len);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, newSeq__systemZio_501)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZrodfiles_89)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NimStringDesc** s);
N_LIB_PRIVATE N_NIMCALL(tySequence__9bAGqSvkAaFL9bWjsEPslrFA*, newSeq__icZic_3260)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3269)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NU32* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__PXIzfWocnrafGz5p3CP5LA*, newSeq__icZic_3310)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3328)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__0q9cmhneJEKnQERTpXXdz6Q* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__IHUFRsFxZNv7YydiUO2esQ*, newSeq__icZic_3372)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3390)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI64* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__b89aLriiJnVTD186H6zNIgg*, newSeq__icZic_3426)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3444)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw*, newSeq__icZic_3489)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3507)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__PsEhl3dzznmmJiLAuIXZOg* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__48JTohSgTy339bRxHzUD8KA*, newSeq__icZic_3552)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3570)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI32* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__QnmOtn1Iv4LvxOXoMn8Rbg*, newSeq__icZic_3614)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3641)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__4Murtwnm0Fyc7F9acrytEXw*, newSeq__icZic_3682)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3691)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__q9bTuOB0JXh1iZ3CSGdRLbg*, newSeq__icZic_3740)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3758)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw*, newSeq__icZic_3799)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3817)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw* x);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3835)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg* x);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3863)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg* x);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3891)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw* x);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3919)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__lo3S1lKyiPLhGGB9cBawd6A** s);
N_LIB_PRIVATE N_NIMCALL(tySequence__lo3S1lKyiPLhGGB9cBawd6A*, newSeq__icZic_3083)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3938)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ* x);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3966)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI32* x);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4012)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI16* x);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4037)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI16* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__oKtVqsc9bQVCNyrijELM4OQ*, newSeq__icZic_4090)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4108)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Db8CrQifKGIsKc3w71w7Lw* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__qy6Iwdy00wN560qud54HTg*, newSeq__icZic_4149)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4167)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__k67v9bwvvQDmS1ynyGGUbeQ*, newSeq__icZic_4216)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4243)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ* x);
N_LIB_PRIVATE N_NIMCALL(tySequence__cLsClAAfd0MKkoBQVyvdvw*, newSeq__icZic_4284)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4311)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__FEYH9alRJhHD0uTKF2vnIqw* x);
N_LIB_PRIVATE N_NIMCALL(void, close__systemZio_217)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(NI, writeBytes__icZrodfiles_123)(FILE* f, NU8* a, NI aLen_0, NI start, NI len);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZrodfiles_221)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA x);
N_LIB_PRIVATE N_NIMCALL(NI, writeBuffer__systemZio_176)(FILE* f, void* buffer, NI len);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZrodfiles_64)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4503)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NU32 x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4553)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__0q9cmhneJEKnQERTpXXdz6Q x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4615)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4670)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4725)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__PsEhl3dzznmmJiLAuIXZOg x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4780)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI32 x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4843)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4893)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA* x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4951)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA* x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5001)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw* x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5019)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5038)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5057)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw x);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_5076)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__lo3S1lKyiPLhGGB9cBawd6A* s);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5110)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5129)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI32 x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5166)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI16 x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5191)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI16 x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5254)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Db8CrQifKGIsKc3w71w7Lw x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5305)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5373)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5424)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__FEYH9alRJhHD0uTKF2vnIqw x);
N_LIB_PRIVATE NIM_CONST tyArray__cdsir9aPB24hAk6k77P9b9bCA cookie__icZrodfiles_51 = {((NU8) 0),
((NU8) 82),
((NU8) 79),
((NU8) 68),
((NU8) 32),
((NU8) 0),
((NU8) 0),
((NU8) 1)}
;
N_LIB_PRIVATE TNimType NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, setError__icZrodfiles_52)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg err) {
	(*f).err = err;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ, open__icZrodfiles_295)(NimStringDesc* filename) {
	tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ result;
	nimZeroMem((void*)(&result), sizeof(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = open__systemZio_389(&result.f, filename, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0), ((NI) -1));
		if (!!(T3_)) goto LA4_;
		setError__icZrodfiles_52((&result), ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 2));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, loadHeader__icZrodfiles_138)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f) {
	tyArray__cdsir9aPB24hAk6k77P9b9bCA thisCookie;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	nimZeroMem((void*)thisCookie, sizeof(tyArray__cdsir9aPB24hAk6k77P9b9bCA));
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBytes__icZrodfiles_159((*f).f, thisCookie, 8, ((NI) 0), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = eqeq___icZrodfiles_173(thisCookie, cookie__icZrodfiles_51);
		if (!!(T11_)) goto LA12_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 4));
	}
	goto LA5_;
	LA12_: ;
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZrodfiles_264)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 1));
		if (!!((T7_ == ((NI) 1)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSection__icZrodfiles_256)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA expected) {
	tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA s;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	s = (tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA)0;
	loadPrim__icZrodfiles_264(f, (&s));
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = !((expected == s));
		if (!(T7_)) goto LA8_;
		T7_ = ((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0));
		LA8_: ;
		if (!T7_) goto LA9_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 5));
	}
	LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZrodfiles_89)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NimStringDesc** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), mnewString(((NI) (lenPrefix))));
		{
			if (!(((NI32) 0) < lenPrefix)) goto LA13_;
			{
				NI T17_;
				T17_ = (NI)0;
				T17_ = readBuffer__systemZio_144((*f).f, ((void*) ((&(*s)->data[((NI) 0)]))), ((NI) (((*s) ? (*s)->Sup.len : 0))));
				if (!!((T17_ == ((*s) ? (*s)->Sup.len : 0)))) goto LA18_;
				setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
			}
			LA18_: ;
		}
		LA13_: ;
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3158)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3184)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 16));
		if (!!((T7_ == ((NI) 16)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3226)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__sM4lkSb7zS6F7OVMvW9cffQ** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__systemZio_501(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZrodfiles_89(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3269)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NU32* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3245)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__9bAGqSvkAaFL9bWjsEPslrFA** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_3260(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_3269(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3328)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__0q9cmhneJEKnQERTpXXdz6Q* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	loadPrim__icZic_3269(f, (&(*x).Field0));
	loadPrim__icZrodfiles_89(f, (&(*x).Field1));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3295)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__PXIzfWocnrafGz5p3CP5LA** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_3310(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_3328(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3390)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI64* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3357)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__IHUFRsFxZNv7YydiUO2esQ** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_3372(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_3390(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3444)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3411)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__b89aLriiJnVTD186H6zNIgg** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_3426(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_3444(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3507)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__PsEhl3dzznmmJiLAuIXZOg* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 12));
		if (!!((T7_ == ((NI) 12)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3474)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_3489(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_3507(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3570)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI32* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3537)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__48JTohSgTy339bRxHzUD8KA** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_3552(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_3570(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3641)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 16));
		if (!!((T7_ == ((NI) 16)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3599)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__QnmOtn1Iv4LvxOXoMn8Rbg** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_3614(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_3641(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3691)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 28));
		if (!!((T7_ == ((NI) 28)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3667)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__4Murtwnm0Fyc7F9acrytEXw** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_3682(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_3691(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3758)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 104));
		if (!!((T7_ == ((NI) 104)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3725)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__q9bTuOB0JXh1iZ3CSGdRLbg** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_3740(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_3758(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3835)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 1));
		if (!!((T7_ == ((NI) 1)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3863)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 1));
		if (!!((T7_ == ((NI) 1)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3891)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3938)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3919)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__lo3S1lKyiPLhGGB9cBawd6A** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_3083(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_3938(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3966)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI32* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4012)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI16* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 2));
		if (!!((T7_ == ((NI) 2)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4037)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI16* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 2));
		if (!!((T7_ == ((NI) 2)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3817)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	loadPrim__icZic_3835(f, (&(*x).kind));
	loadPrim__icZic_3863(f, (&(*x).callConv));
	loadPrim__icZic_3891(f, (&(*x).flags));
	loadSeq__icZic_3919(f, (&(*x).types));
	loadPrim__icZic_3966(f, (&(*x).n));
	loadPrim__icZic_3938(f, (&(*x).sym));
	loadPrim__icZic_3938(f, (&(*x).owner));
	loadPrim__icZic_3390(f, (&(*x).size));
	loadPrim__icZic_4012(f, (&(*x).align));
	loadPrim__icZic_4012(f, (&(*x).paddingAtEnd));
	loadPrim__icZic_4037(f, (&(*x).lockLevel));
	loadPrim__icZic_3938(f, (&(*x).typeInst));
	loadPrim__icZic_3570(f, (&(*x).nonUniqueId));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3784)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_3799(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_3817(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4108)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Db8CrQifKGIsKc3w71w7Lw* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 16));
		if (!!((T7_ == ((NI) 16)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_4075)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__oKtVqsc9bQVCNyrijELM4OQ** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_4090(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_4108(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4167)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	loadPrim__icZic_3938(f, (&(*x).key));
	loadPrim__icZic_3938(f, (&(*x).sym));
	loadSeq__icZic_3919(f, (&(*x).concreteTypes));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_4134)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__qy6Iwdy00wN560qud54HTg** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_4149(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_4167(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4243)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 20));
		if (!!((T7_ == ((NI) 20)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_4201)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__k67v9bwvvQDmS1ynyGGUbeQ** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_4216(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_4243(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4311)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__FEYH9alRJhHD0uTKF2vnIqw* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 20));
		if (!!((T7_ == ((NI) 20)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_4269)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__cLsClAAfd0MKkoBQVyvdvw** s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	lenPrefix = ((NI32) 0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA5_;
	LA8_: ;
	{
		unsureAsgnRef((void**) (&(*s)), newSeq__icZic_4284(((NI) (lenPrefix))));
		{
			NI32 i;
			NI32 res;
			i = (NI32)0;
			res = ((NI32) 0);
			{
				while (1) {
					if (!(res < lenPrefix)) goto LA13;
					i = res;
					loadPrim__icZic_4311(f, (&(*s)->data[i]));
					res += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4345)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__systemZio_144((*f).f, ((void*) (x)), ((NI) 1));
		if (!!((T7_ == ((NI) 1)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, close__icZrodfiles_293)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f) {
	close__systemZio_217((*f).f);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ, create__icZrodfiles_290)(NimStringDesc* filename) {
	tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ result;
	nimZeroMem((void*)(&result), sizeof(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = open__systemZio_389(&result.f, filename, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 1), ((NI) -1));
		if (!!(T3_)) goto LA4_;
		setError__icZrodfiles_52((&result), ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 2));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, storeHeader__icZrodfiles_109)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBytes__icZrodfiles_123((*f).f, cookie__icZrodfiles_51, 8, ((NI) 0), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZrodfiles_221)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 1));
		if (!!((T7_ == ((NI) 1)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSection__icZrodfiles_207)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA s) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	(*f).currentSection = s;
	storePrim__icZrodfiles_221(f, s);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZrodfiles_64)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NimStringDesc* s) {
	NI32 lenPrefix;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!(((NI) 2147483647) <= (s ? s->Sup.len : 0))) goto LA7_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA7_: ;
	lenPrefix = ((NI32) ((s ? s->Sup.len : 0)));
	{
		NI T11_;
		T11_ = (NI)0;
		T11_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T11_ == ((NI) 4)))) goto LA12_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA9_;
	LA12_: ;
	{
		{
			if (!!(((s ? s->Sup.len : 0) == ((NI) 0)))) goto LA17_;
			{
				NI T21_;
				T21_ = (NI)0;
				T21_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&s->data[((NI) 0)]))), ((NI) ((s ? s->Sup.len : 0))));
				if (!!((T21_ == (s ? s->Sup.len : 0)))) goto LA22_;
				setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
			}
			LA22_: ;
		}
		LA17_: ;
	}
	LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4391)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4408)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 16));
		if (!!((T7_ == ((NI) 16)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4437)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZrodfiles_64(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4503)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NU32 x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4470)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__9bAGqSvkAaFL9bWjsEPslrFA* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_4503(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4553)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__0q9cmhneJEKnQERTpXXdz6Q x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	storePrim__icZic_4503(f, x.Field0);
	storePrim__icZrodfiles_64(f, x.Field1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4520)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__PXIzfWocnrafGz5p3CP5LA* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_4553(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4615)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI64 x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4582)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__IHUFRsFxZNv7YydiUO2esQ* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_4615(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4670)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4636)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__b89aLriiJnVTD186H6zNIgg* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_4670(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4725)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__PsEhl3dzznmmJiLAuIXZOg x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 12));
		if (!!((T7_ == ((NI) 12)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4691)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_4725(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4780)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI32 x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4746)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__48JTohSgTy339bRxHzUD8KA* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_4780(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4843)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 16));
		if (!!((T7_ == ((NI) 16)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4809)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_4843(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4893)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) (x)), ((NI) 28));
		if (!!((T7_ == ((NI) 28)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4860)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__4Murtwnm0Fyc7F9acrytEXw* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_4893(f, (&s->data[i]));
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4951)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) (x)), ((NI) 104));
		if (!!((T7_ == ((NI) 104)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4918)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_4951(f, (&s->data[i]));
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5019)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 1));
		if (!!((T7_ == ((NI) 1)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5038)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 1));
		if (!!((T7_ == ((NI) 1)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5057)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5110)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 8));
		if (!!((T7_ == ((NI) 8)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_5076)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__lo3S1lKyiPLhGGB9cBawd6A* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_5110(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5129)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI32 x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 4));
		if (!!((T7_ == ((NI) 4)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5166)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI16 x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 2));
		if (!!((T7_ == ((NI) 2)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5191)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NI16 x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 2));
		if (!!((T7_ == ((NI) 2)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5001)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw* x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	storePrim__icZic_5019(f, (*x).kind);
	storePrim__icZic_5038(f, (*x).callConv);
	storePrim__icZic_5057(f, (*x).flags);
	storeSeq__icZic_5076(f, (*x).types);
	storePrim__icZic_5129(f, (*x).n);
	storePrim__icZic_5110(f, (*x).sym);
	storePrim__icZic_5110(f, (*x).owner);
	storePrim__icZic_4615(f, (*x).size);
	storePrim__icZic_5166(f, (*x).align);
	storePrim__icZic_5166(f, (*x).paddingAtEnd);
	storePrim__icZic_5191(f, (*x).lockLevel);
	storePrim__icZic_5110(f, (*x).typeInst);
	storePrim__icZic_4780(f, (*x).nonUniqueId);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4968)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_5001(f, (&s->data[i]));
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5254)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Db8CrQifKGIsKc3w71w7Lw x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 16));
		if (!!((T7_ == ((NI) 16)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_5220)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__oKtVqsc9bQVCNyrijELM4OQ* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_5254(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5305)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	storePrim__icZic_5110(f, x.key);
	storePrim__icZic_5110(f, x.sym);
	storeSeq__icZic_5076(f, x.concreteTypes);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_5271)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__qy6Iwdy00wN560qud54HTg* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_5305(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5373)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 20));
		if (!!((T7_ == ((NI) 20)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_5339)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__k67v9bwvvQDmS1ynyGGUbeQ* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_5373(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5424)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyTuple__FEYH9alRJhHD0uTKF2vnIqw x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 20));
		if (!!((T7_ == ((NI) 20)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_5390)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__cLsClAAfd0MKkoBQVyvdvw* s) {
	NI32 lenPrefix;
	NI T10_;
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (s ? s->Sup.len : 0);
		if (!(((NI) 2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 1));
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = (s ? s->Sup.len : 0);
	lenPrefix = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&lenPrefix))), ((NI) 4));
		if (!!((T13_ == ((NI) 4)))) goto LA14_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	goto LA11_;
	LA14_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T18_ = (s ? s->Sup.len : 0);
			colontmp_ = T18_;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					storePrim__icZic_5424(f, s->data[i]);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5449)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ x) {
{	{
		if (!!(((*f).err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__systemZio_176((*f).f, ((void*) ((&x))), ((NI) 1));
		if (!!((T7_ == ((NI) 1)))) goto LA8_;
		setError__icZrodfiles_52(f, ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 3));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, atmicatsrodfilesdotnim_DatInit000)(void) {
static TNimNode* TM__P1yRI9ajFdGwsyRsqLNBVHw_2_8[8];
NI TM__P1yRI9ajFdGwsyRsqLNBVHw_4;
static char* NIM_CONST TM__P1yRI9ajFdGwsyRsqLNBVHw_3[8] = {
"ok", 
"tooBig", 
"cannotOpen", 
"ioFailure", 
"wrongHeader", 
"wrongSection", 
"configMismatch", 
"includeFileChanged"};
static TNimNode TM__P1yRI9ajFdGwsyRsqLNBVHw_0[9];
NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_.size = sizeof(tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg);
NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_.align = NIM_ALIGNOF(tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg);
NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_.kind = 14;
NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_.base = 0;
NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_.flags = 3;
for (TM__P1yRI9ajFdGwsyRsqLNBVHw_4 = 0; TM__P1yRI9ajFdGwsyRsqLNBVHw_4 < 8; TM__P1yRI9ajFdGwsyRsqLNBVHw_4++) {
TM__P1yRI9ajFdGwsyRsqLNBVHw_0[TM__P1yRI9ajFdGwsyRsqLNBVHw_4+0].kind = 1;
TM__P1yRI9ajFdGwsyRsqLNBVHw_0[TM__P1yRI9ajFdGwsyRsqLNBVHw_4+0].offset = TM__P1yRI9ajFdGwsyRsqLNBVHw_4;
TM__P1yRI9ajFdGwsyRsqLNBVHw_0[TM__P1yRI9ajFdGwsyRsqLNBVHw_4+0].name = TM__P1yRI9ajFdGwsyRsqLNBVHw_3[TM__P1yRI9ajFdGwsyRsqLNBVHw_4];
TM__P1yRI9ajFdGwsyRsqLNBVHw_2_8[TM__P1yRI9ajFdGwsyRsqLNBVHw_4] = &TM__P1yRI9ajFdGwsyRsqLNBVHw_0[TM__P1yRI9ajFdGwsyRsqLNBVHw_4+0];
}
TM__P1yRI9ajFdGwsyRsqLNBVHw_0[8].len = 8; TM__P1yRI9ajFdGwsyRsqLNBVHw_0[8].kind = 2; TM__P1yRI9ajFdGwsyRsqLNBVHw_0[8].sons = &TM__P1yRI9ajFdGwsyRsqLNBVHw_2_8[0];
NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_.node = &TM__P1yRI9ajFdGwsyRsqLNBVHw_0[8];
}

